#[non_exhaustive]pub enum JoinPlanError {
UnsupportedJoinType {
join_type: JoinType,
},
UnsupportedJoinConstraint {
constraint: JoinConstraint,
},
UnsupportedPredicate {
left: String,
right: String,
},
}Expand description
Errors encountered while converting a join logical plan.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
UnsupportedJoinType
Only inner joins can be converted to the current proof plan.
UnsupportedJoinConstraint
Only ON join constraints can be converted to the current proof plan.
Fields

constraint: JoinConstraintUnsupported join constraint.
UnsupportedPredicate
The join predicate is not a supported pair of matching column references.