#[non_exhaustive]pub enum PlannerError {
Show 18 variants
AnalyzeError {
source: AnalyzeError,
},
DecimalError {
source: DecimalError,
},
SqlParserError {
source: ParserError,
},
DataFusionError {
source: DataFusionError,
},
ColumnNotFound,
TableNotFound {
table_name: String,
},
InvalidPlaceholderId {
id: String,
},
UntypedPlaceholder {
placeholder: Placeholder,
},
UnsupportedDataType {
data_type: DataType,
},
UnsupportedBinaryOperator {
op: Operator,
},
UnsupportedAggregateOperation {
op: AggregateFunction,
},
UnsupportedAggregateFunction {
function: AggregateFunction,
},
UnsupportedLogicalExpression {
expr: Box<Expr>,
},
UnsupportedAggregatePlan {
source: AggregatePlanError,
},
UnsupportedJoinPlan {
source: JoinPlanError,
},
UnsupportedLogicalPlan {
node: LogicalPlanNodeKind,
},
UnresolvedLogicalPlan,
CatalogNotSupported,
}Expand description
Proof of SQL Planner error
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
AnalyzeError
Returned when the internal analyze process fails
Fields
source: AnalyzeErrorUnderlying analyze error
DecimalError
Returned when a decimal error occurs
Fields
source: DecimalErrorUnderlying decimal error
SqlParserError
Returned when sqlparser fails to parse a query
Fields
source: ParserErrorUnderlying sqlparser error
DataFusionError
Returned when datafusion fails to plan a query
Fields
source: DataFusionErrorUnderlying datafusion error
ColumnNotFound
Returned if a column is not found
TableNotFound
Returned if a table is not found
InvalidPlaceholderId
Returned when a placeholder id is invalid
UntypedPlaceholder
Returned when a placeholder is untyped
Fields
placeholder: PlaceholderUntyped placeholder
UnsupportedDataType
Returned when a datatype is not supported
UnsupportedBinaryOperator
Returned when a binary operator is not supported
UnsupportedAggregateOperation
Returned when the aggregate opetation is not supported
Fields
op: AggregateFunctionUnsupported aggregate operation
UnsupportedAggregateFunction
Returned when the AggregateFunction is not supported
Fields
function: AggregateFunctionUnsupported AggregateFunction
UnsupportedLogicalExpression
Returned when a logical expression is not resolved
UnsupportedAggregatePlan
Returned when an aggregate logical plan cannot be converted.
Fields
source: AggregatePlanErrorSpecific aggregate conversion error.
UnsupportedJoinPlan
Returned when a join logical plan cannot be converted.
Fields
source: JoinPlanErrorSpecific join conversion error.
UnsupportedLogicalPlan
Returned when a LogicalPlan node or shape is not supported.
Fields
node: LogicalPlanNodeKindKind of node whose particular shape was unsupported.
UnresolvedLogicalPlan
Returned when the LogicalPlan is not resolved
CatalogNotSupported
Returned when catalog is provided since it is not supported